Index: trunk/info/info/alkisn/alkisgebaeudenw.php
===================================================================
--- trunk/info/info/alkisn/alkisgebaeudenw.php	(revision 389)
+++ trunk/info/info/alkisn/alkisgebaeudenw.php	(revision 402)
@@ -9,8 +9,8 @@
 	2017-06-08 Validierung Eingabeparameter, Feinkorrekturen
 	2017-06-19 Tool-Tip GebÃ€udefunktion
+	2018-04-23 Kennzeichen eingerÃŒckt, &nodebug
 */
 session_start();
-
-$showkey="n"; // Var. aus Parameter initalisieren
+$showkey="n"; $nodebug=""; // Var. aus Parameter initalisieren
 $cntget = extract($_GET); // Parameter in Variable umwandeln
 
@@ -20,9 +20,10 @@
 if (!preg_match('#^[j|n]{0,1}$#', $showkey)) {die ("Eingabefehler showkey");}
 if ($showkey == "j") {$showkey=true;} else {$showkey=false;}
+if (!preg_match('#^j{0,1}$#', $nodebug)) {die("Eingabefehler nodebug");}
 
 require_once("alkis_conf_location.php");
 if ($auth == "mapbender") {require_once($mapbender);}
 include("alkisfkt.php");
-?>
+echo <<<END
 <!doctype html>
 <html lang="de">
@@ -35,10 +36,14 @@
 </head>
 <body>
-<?php
+END;
+// Mit URL-Parameter "&nodebug=j" kann man die Entwicklungsumgebung (in Conf definiert) ausschalten.
+// Manuell an die URL anfÃŒgen, wirkt nur temporÃ€r und wird nicht in Links weiter gereicht.
+if ($nodebug == "j") {$debug=0;} 
+
 $con = pg_connect($dbconn." options='--application_name=ALKIS-Auskunft_alkisgebaeudenw.php'");
 if (!$con) echo "\n<p class='err'>Fehler beim Verbinden der DB</p>";
 
 // Flurstueck
-$sqlf ="SELECT f.name, f.flurnummer, f.zaehler, f.nenner, f.amtlicheflaeche, f.zeitpunktderentstehung, g.gemarkungsnummer, g.bezeichnung 
+$sqlf="SELECT f.name, f.flurnummer, f.zaehler, f.nenner, f.amtlicheflaeche, f.zeitpunktderentstehung, g.gemarkungsnummer, g.bezeichnung 
 FROM ax_flurstueck f LEFT JOIN ax_gemarkung g ON f.land=g.land AND f.gemarkungsnummer=g.gemarkungsnummer 
 WHERE f.gml_id= $1 AND f.endet IS NULL AND g.endet IS NULL;";
@@ -50,6 +55,5 @@
 	if ($debug > 2) {echo "\n<p class='err'>SQL=<br>".$sqlf."<br>$1 = gml_id = '".$gmlid."'</p>";}
 }
-
-if ($rowf = pg_fetch_array($resf)) {
+if ($rowf = pg_fetch_assoc($resf)) {
 	$gemkname=htmlentities($rowf["bezeichnung"], ENT_QUOTES, "UTF-8");
 	$gmkgnr=$rowf["gemarkungsnummer"];
@@ -64,35 +68,34 @@
 	echo "\n<p class='err'>Fehler! Kein Treffer fuer gml_id=".$gmlid."</p>";
 }
-
-// Balken
-echo "<p class='geb'>ALKIS Flurst&uuml;ck (Geb&auml;ude) ".$gmkgnr."-".$flurnummer."-".$flstnummer."&nbsp;</p>";
-
-echo "\n<h2><img src='ico/Flurstueck.png' width='16' height='16' alt=''> Flurst&uuml;ck (Geb&auml;ude)</h2>";
-
-// Kennzeichen in Rahmen
-echo "\n<table class='outer'>\n<tr>\n<td>"
-	."\n\t<table class='kennzfs' title='Flurst&uuml;ckskennzeichen'>"
-    ."\n\t<tr>"
-        ."\n\t\t<td class='head'>Gmkg</td>"
-        ."\n\t\t<td class='head'>Flur</td>"
-        ."\n\t\t<td class='head'>Flurst-Nr.</td>"
-    ."\n\t</tr>\n\t<tr>"
-        ."\n\t\t<td title='Gemarkung'>";
-        if  ($showkey) {echo "<span class='key'>".$gmkgnr."</span><br>";}
-        echo $gemkname."&nbsp;</td>"
-        ."\n\t\t<td title='Flurnummer'>".$flurnummer."</td>"
-        ."\n\t\t<td title='Flurst&uuml;cksnummer (Z&auml;hler / Nenner)'><span class='wichtig'>".$flstnummer."</span></td>"
-    ."\n\t</tr>"
-	."\n\t</table>"
-."\n</td>\n<td>";
-
-// Links zu anderem Nachweis
-echo "\n\t<p class='nwlink noprint'>"
-	."\n\t\t<a href='alkisfsnw.php?gkz=".$gkz."&amp;gmlid=".$gmlid;
-	if ($showkey) {echo "&amp;showkey=j";}
-	echo "&amp;eig=n' title='Flurst&uuml;cksnachweis'>Flurst&uuml;ck <img src='ico/Flurstueck_Link.png' width='16' height='16' alt=''></a>"
-."\n\t</p>"
-."\n\t</td>\n</tr>\n</table>";
-// Ende Seitenkopf
+echo "<p class='geb'>ALKIS Flurst&uuml;ck (Geb&auml;ude) ".$gmkgnr."-".$flurnummer."-".$flstnummer."&nbsp;</p>"; // Balken
+echo "\n<h2>Flurst&uuml;ck (Geb&auml;ude)</h2>";
+echo "\n<table class='outer'>" // Kopf
+	."\n<tr>"
+		."\n\t<td>"
+		."\n\t<td class='ll'><img src='ico/Flurstueck.png' width='16' height='16' alt=''> Kennzeichen:</td>"
+		."\n\t<td>"
+			."\n\t\t<table class='kennzfs' title='Flurst&uuml;ckskennzeichen'>" // Kennzeichen in Rahmen
+				."\n\t\t<tr>"
+					."\n\t\t\t<td class='head'>Gemarkung</td>"
+					."\n\t\t\t<td class='head'>Flur</td>"
+					."\n\t\t\t<td class='head'>Flurst-Nr.</td>"
+				."\n\t\t</tr>\n\t\t<tr>"
+					."\n\t\t\t<td title='Gemarkung'>";
+					if  ($showkey) {echo "<span class='key'>".$gmkgnr."</span><br>";}
+					echo $gemkname."&nbsp;</td>"
+					."\n\t\t\t<td title='Flurnummer'>".$flurnummer."</td>"
+					."\n\t\t\t<td title='Flurst&uuml;cksnummer (Z&auml;hler / Nenner)'><span class='wichtig'>".$flstnummer."</span></td>"
+				."\n\t\t</tr>"
+			."\n\t\t</table>"
+		."\n\t</td>"
+		."\n\t<td>"
+			."\n\t\t<p class='nwlink noprint'>" // Links zu anderem Nachweis
+				."\n\t\t\t<a href='alkisfsnw.php?gkz=".$gkz."&amp;gmlid=".$gmlid;
+				if ($showkey) {echo "&amp;showkey=j";}
+				echo "&amp;eig=n' title='Flurst&uuml;cksnachweis'>Flurst&uuml;ck <img src='ico/Flurstueck_Link.png' width='16' height='16' alt=''></a>"
+			."\n\t\t</p>"
+		."\n\t</td>"
+	."\n</tr>"
+."\n</table>";
 
 echo "\n<p class='fsd'>Flurst&uuml;cksfl&auml;che: <b>".number_format($flstflaeche,0,",",".") . " m&#178;</b></p>";
@@ -129,6 +132,5 @@
 $gebflsum=0;
 echo "\n<hr>\n<table class='geb'>";
-	// T-Header
-	echo "\n<tr>\n"
+	echo "\n<tr>" // T-Header
 		."\n\t<td class='head' title='ggf. Geb&auml;udename'>Name</td>"
 		."\n\t<td class='heads fla' title='Schnittfl&auml;che zwischen Flurst&uuml;ck und Geb&auml;ude'><img src='ico/sortd.png' width='10' height='10' alt='' title='Sortierung (absteigend)'>Fl&auml;che</td>"
@@ -140,11 +142,10 @@
 		."\n\t<td class='head nwlink' title='Link zu den kompletten Hausdaten'>Haus</td>"
 	."\n</tr>";
-	// T-Body
-	while($rowg = pg_fetch_array($resg)) {
+	while($rowg = pg_fetch_assoc($resg)) { // T-Body
 		$gebnr = $gebnr + 1;
 		$ggml=$rowg["gml_id"];
 		$gebflsum=$gebflsum + $rowg["schnittflae"];
-		$gnam= trim(trim($rowg["name"], "{}"), '"'); // Gebaeude-Name ist ein Array in der DB: '{"A","B"}'
-		// Mehrfachbelegung nur theoretisch. Entklammern reicht. Mal mit und mal ohne "" drum !?
+		$gnam=trim(trim($rowg["name"], "{}"), '"'); // Gebaeude-Name ist ein Array in der DB: '{"A","B"}'
+		// Mehrfachbelegung nur theoretisch. Entklammern reicht. Mal mit und mal ohne "" drum!?
 		/* SELECT name FROM ax_gebaeude WHERE NOT name IS NULL AND array_length(name, 1) > 1; */
 		$gfktk=htmlentities($rowg["gebaeudefunktion"], ENT_QUOTES, "UTF-8");  // Geb.-Funktion Key
@@ -174,5 +175,5 @@
 			."\n\t<td class='".$gstyle."'>"; // Sp. 1 Name
 			if ($gnam != "") {echo "<span title='Geb&auml;udename'>".$gnam."</span><br>";}
-			echo "\n\t</td>";
+			echo "</td>";
 
 			echo "\n\t<td class='fla'>".$f1."</td>" // Sp. 2
@@ -191,7 +192,8 @@
 			echo $gzustand."&nbsp;</td>";
 
-			echo "\n\t<td class='nwlink noprint'>";
-			// 0 bis N Lagebezeichnungen mit Haus- oder Pseudo-Nummer, alle in ein TD zu EINEM GebÃ€ude
-
+			// 2 Spalten mit Links zu anderen Nachweisen: 1. Lage, 2. GebÃ€ude
+			echo "\n\t<td class='nwlink noprint'>"; // Link Lage
+
+			// Zu EINEM GebÃ€ude mehrere Lagebezeichnungen mit Haus- oder Pseudo-Nummer mÃ¶glich, alle in ein TD 
 			// HAUPTgebÃ€ude  Geb >zeigtAuf> lage (mehrere)
 			$sqll="SELECT 'm' AS ltyp, l.gml_id AS lgml, s.lage, s.bezeichnung, l.hausnummer, '' AS laufendenummer "
@@ -200,5 +202,5 @@
 			."WHERE g.gml_id= $1 AND g.endet IS NULL AND l.endet IS NULL AND s.endet IS NULL ";
 
-			// oder NEBENgebÃ€ude  Geb >hat> Pseudo
+			// UNION - oder NEBENgebÃ€ude  Geb >hat> Pseudo
 			$sqll.="UNION SELECT 'p' AS ltyp, l.gml_id AS lgml, s.lage, s.bezeichnung, l.pseudonummer AS hausnummer, l.laufendenummer "
 			."FROM ax_gebaeude g JOIN ax_lagebezeichnungmitpseudonummer l ON l.gml_id=g.hat "
@@ -207,5 +209,4 @@
 		
 			$sqll.="ORDER BY bezeichnung, hausnummer;";
-
 			$v = array($ggml);
 			$resl = pg_prepare("", $sqll);
@@ -215,5 +216,5 @@
 				if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".$sqll."<br>$1 = gml_id = '".$gmlid."'</p>";}
 			}
-			while($rowl = pg_fetch_array($resl)) { // LOOP: Lagezeilen
+			while($rowl = pg_fetch_assoc($resl)) { // LOOP: Lagezeilen
 				$ltyp=$rowl["ltyp"]; // Lagezeilen-Typ
 				$skey=$rowl["lage"]; // Str.-Schluessel
@@ -229,21 +230,21 @@
 					$lagetxt=$snam."&nbsp;".$hsnr;
 				}
-				echo "\n\t\t<img src='ico/Lage_mit_Haus.png' width='16' height='16' alt=''>&nbsp;";
-				if ($showkey) {echo "<span class='key'>(".$skey.")</span>&nbsp;";}			
 				echo "\n\t\t<a title='".$lagetitl."' href='alkislage.php?gkz=".$gkz."&amp;gmlid=".$gmllag."&amp;ltyp=".$ltyp;
-					if ($showkey)   {echo "&amp;showkey=j";}
-				echo "'>".$lagetxt."</a>";
-				echo "<br>";
+					if ($showkey) {echo "&amp;showkey=j";}
+					echo "'>";
+					if ($showkey) {echo "<span class='key'>(".$skey.")</span>&nbsp;";}
+				echo $lagetxt."&nbsp;<img src='ico/Lage_mit_Haus.png' width='16' height='16' alt=''></a><br>";
 			} // Ende Loop Lage m.H.
             pg_free_result($resl);
 			echo "\n\t</td>";
 
-			echo "\n\t<td class='nwlink noprint'>"
+			echo "\n\t<td class='nwlink noprint'>" // Link Haus
 				."\n\t\t<a title='Daten zum Geb&auml;ude-Objekt' href='alkishaus.php?gkz=".$gkz."&amp;gmlid=".$ggml;
 				if ($showkey) {echo "&amp;showkey=j";}
-				echo "'><img src='ico/Haus.png' width='16' height='16' alt=''></a>"
+				echo "'>Haus&nbsp;<img src='ico/Haus.png' width='16' height='16' alt=''></a>"
 			."\n\t</td>"
 		."\n</tr>";
-	}
+	} // Ende GebÃ€ude
+
 	// Footer
 	if ($gebnr == 0) {
@@ -258,11 +259,11 @@
 	."\n</table>";
 	$unbebaut = number_format(($flstflaeche - $gebflsum),0,",",".") . " m&#178;";
-	echo "\n<p><br>Flurst&uuml;cksfl&auml;che abz&uuml;glich Geb&auml;udefl&auml;che: <b>".$unbebaut."</b></p><br>";
+	echo "\n<p>\n<br>Flurst&uuml;cksfl&auml;che abz&uuml;glich Geb&auml;udefl&auml;che: <b>".$unbebaut."</b></p>\n<br>";
 }
 pg_free_result($resg);
 ?>
-
+ 
 <div class='buttonbereich noprint'>
-<hr>
+	<hr>
 	<a title="zur&uuml;ck" href='javascript:history.back()'><img src="ico/zurueck.png" width="16" height="16" alt="zur&uuml;ck"></a>&nbsp;
 	<a title="Drucken" href='javascript:window.print()'><img src="ico/print.png" width="16" height="16" alt="Drucken"></a>
